==> haskell-tasty-hedgehog-1.4.0.1-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-hedgehog
version:              1.4.0.1
visibility:           public
id:                   tasty-hedgehog-1.4.0.1-9vZgGRe5NDM2hy6Ct65sDC
key:                  tasty-hedgehog-1.4.0.1-9vZgGRe5NDM2hy6Ct65sDC
license:              BSD-3-Clause
copyright:
    Copyright (c) 2017, Commonwealth Scientific and Industrial Research Organisation (CSIRO) ABN 41 687 119 230.

maintainer:           dave.laing.80@gmail.com
author:               Dave Laing
homepage:             https://github.com/qfpl/tasty-hedgehog
synopsis:             Integration for tasty and hedgehog.
description:
    Integrates the <https://hackage.haskell.org/package/hedgehog hedgehog testing library> with the <https://hackage.haskell.org/package/tasty tasty testing framework>.

category:             Testing
abi:                  d2fae97621afc52e86d4b15ea6dce628
exposed:              True
exposed-modules:      Test.Tasty.Hedgehog
import-dirs:          /usr/lib/ghc-9.2.8/site-local/tasty-hedgehog-1.4.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tasty-hedgehog-1.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-hedgehog
hs-libraries:         HStasty-hedgehog-1.4.0.1-9vZgGRe5NDM2hy6Ct65sDC
depends:
    base-4.16.4.0 hedgehog-1.2-8AOZuLWOKDrFta6N76jC9F
    tagged-0.8.9-KXBukbFHRBNBMyyfjfj7aP
    tasty-1.4.3-KLaZ0I3In7gId0p2C9am4Q

haddock-interfaces:
    /usr/share/doc/haskell-tasty-hedgehog/html/tasty-hedgehog.haddock

haddock-html:         /usr/share/doc/haskell-tasty-hedgehog/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-hedgehog-1.4.0.1-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-hedgehog
version:              1.4.0.1
visibility:           public
id:                   tasty-hedgehog-1.4.0.1-7icWGqKHlLFAXbUcB4GW3q
key:                  tasty-hedgehog-1.4.0.1-7icWGqKHlLFAXbUcB4GW3q
license:              BSD-3-Clause
copyright:
    Copyright (c) 2017, Commonwealth Scientific and Industrial Research Organisation (CSIRO) ABN 41 687 119 230.

maintainer:           dave.laing.80@gmail.com
author:               Dave Laing
homepage:             https://github.com/qfpl/tasty-hedgehog
synopsis:             Integration for tasty and hedgehog.
description:
    Integrates the <https://hackage.haskell.org/package/hedgehog hedgehog testing library> with the <https://hackage.haskell.org/package/tasty tasty testing framework>.

category:             Testing
abi:                  cb2cfae995af4fd766f2c589a6ac53c2
exposed:              True
exposed-modules:      Test.Tasty.Hedgehog
import-dirs:          /usr/lib/ghc-9.2.8/site-local/tasty-hedgehog-1.4.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tasty-hedgehog-1.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-hedgehog
hs-libraries:         HStasty-hedgehog-1.4.0.1-7icWGqKHlLFAXbUcB4GW3q
depends:
    base-4.16.4.0 hedgehog-1.2-5fDoEx04zV2G0uUliXNEoH
    tagged-0.8.9-KXBukbFHRBNBMyyfjfj7aP
    tasty-1.4.3-6DoLeDu8RfYA7wNokjealu

haddock-interfaces:
    /usr/share/doc/haskell-tasty-hedgehog/html/tasty-hedgehog.haddock

haddock-html:         /usr/share/doc/haskell-tasty-hedgehog/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
